matrix input A =  (1    ,  0   , 0   , 0   \  /// rtp_t
				   -0.05,  1   , 0   , 0   \  /// trolley_t
				   -0.05, -0.05, 1   , 0   \  /// metrobus_t
				    0.10,  0.20, 0.10, 1   )   // metro_t

matrix input A1 = (0.15, 0.04, 0.04, 0.15\  /// rtp_t-1
                   0.07, 0.15, 0.04, 0.15\  /// trolley_t-1
                   0.04, 0.04, 0.15, 0.04\  /// metrobus_t-1
				   0.07, 0.04, 0.07, 0.15)   // metro_t-1

matrix input A2 = (0.05, 0.00, 0.00, 0.05\  /// rtp_t-2
                   0.00, 0.05, 0.00, 0.00\  /// trolley_t-2
                   0.00, 0.00, 0.05, 0.01\  /// metrobus_t-2
				   0.01, 0.01, 0.01, 0.05)   // metro_t-2

matrix input B  = (.038,    0,    0,    0\  /// e_rtp
                   0   , .016,    0,    0\  /// e_trolley
                   0   ,    0, .076,    0\  /// e_metrobus
				   0   ,    0,    0, .341)  // e_metro
				   
// Nota: Los parámetros de la matriz B los elegimos calculando, a partir de datos
// mensuales reales, cómo serían más o menos esas desviaciones estándar de los
// datos darios.
			
			
matrix input Phi  = (-.1\ /// rtp_t
                     -.2\ /// trolley_t
                     -.2\ /// metrobus_t
				      .3)  // metro_t

program varstep
	scalar e_metro = rnormal()
	scalar e_metrobus = rnormal()
	scalar z1 = rpoisson(exp(e_metro)) //Instrumento del Metro
	scalar z2 = rpoisson(exp(e_metrobus)) //Instrumento del Metrobus
	matrix et = (rnormal()\rnormal()\e_metrobus\e_metro)
	matrix define yt = inv(A)*A1*`1' +  inv(A)*A2*`2' + inv(A)*Phi*`3' + inv(A)*B*et
end

frame create vardata date d_rtp d_trolley d_metrobus d_metro closed_mtro closed_mbus protest
frame post vardata (19089) (1) (1) (1) (1) (1) (1) (1)
frame post vardata (19090) (1) (1) (1) (1) (1) (1) (1)
frame post vardata (19091) (1) (1) (1) (1) (1) (1) (1)

scalar day = 19092
local i = 4
while day <= date("31dec2019", "DMY"){
	
	scalar x = rbinomial(1,.05)	// Protest day = 1 (an exogenous variable)
	
	if dow(day) == 5{ // If Friday
	frame vardata: matrix tminus1 = (d_rtp[`i'-1]\d_trolley[`i'-1]\d_metrobus[`i'-1]\d_metro[`i'-1])
	frame vardata: matrix tminus2 = (d_rtp[`i'-2]\d_trolley[`i'-2]\d_metrobus[`i'-2]\d_metro[`i'-2])

	varstep tminus1 tminus2 x

	frame post vardata (day) (yt[1,1]) (yt[2,1]) (yt[3,1]) (yt[4,1]) (z1) (z2) (x)
	
	scalar day = day + 3	
	}
	
	else{ // If other days of the week
	frame vardata: matrix tminus1 = (d_rtp[`i'-1]\d_trolley[`i'-1]\d_metrobus[`i'-1]\d_metro[`i'-1])
	frame vardata: matrix tminus2 = (d_rtp[`i'-2]\d_trolley[`i'-2]\d_metrobus[`i'-2]\d_metro[`i'-2])

	varstep tminus1 tminus2 x

	frame post vardata (day) (yt[1,1]) (yt[2,1]) (yt[3,1]) (yt[4,1]) (z1) (z2) (x)
	
	scalar day = day + 1
	}
	
	local i = `i' + 1
}

frame change vardata

format date %td
drop if date < date("05jan2015", "DMY")

label variable d_metro "Pasajeros metro (cambio diario)"
label variable d_metrobus "Pasajeros metrobús (cambio diario)"
label variable d_trolley "Pasajeros trolebús (cambio diario)"
label variable d_rtp "Pasajeros RTP (cambio diario)"
label variable closed_mtro "# de estaciones del metro no disponibles hoy"
label variable closed_mbus "# de estaciones del metrobus no disponibles hoy"
label variable protest "Protesta en avenida principal"

rename d_trolley d_trolebus
rename closed_mtro cerrado_mtro
rename closed_mbus cerrado_mbus
rename protest protesta
rename date fecha

label data "Simulación VAR transporte público Ciudad de México"

// Aquí reemplazamos nuestra variable fecha con una asociada a un
// calendario sin fines de semana, para que Stata no se preocupe de que
// nuestra base no tiene sábados y domingos.
bcal create mycal, from (fecha) replace
bcal load mycal
generate bcaldate = bofd("mycal", fecha)
format %tbmycal bcaldate
drop fecha
rename bcaldate fecha
order fecha, first
tsset fecha

save trasportep.dta, replace